@@ -1,15 +1,14 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from trytond.model import fields
 from trytond.pyson import Eval
 from trytond.pool import PoolMeta
 from . import luhn
 
 __all__ = ['Party']
-__metaclass__ = PoolMeta
 
 
-class Party:
+class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
 
     siren = fields.Char('SIREN', select=True, states={
